@@ -1,41 +1,71 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
+build_time_vars = {'ABIFLAGS': 'm',
+ 'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ATHEOS_THREADS': 0,
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BEOS_THREADS': 0,
  'BINDIR': '/opt/anaconda1anaconda2anaconda3/bin',
- 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python2.7',
- 'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -pthread -shared -L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
+ 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+ 'BLDLIBRARY': '-L. -lpython3.5m',
+ 'BLDSHARED': 'gcc -pthread -shared '
+              '-L/opt/anaconda1anaconda2anaconda3/lib '
+              '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed '
+              '-L/opt/anaconda1anaconda2anaconda3/lib '
+              '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
+ 'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
+ 'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -g -O2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
+           '-Wstrict-prototypes',
  'CFLAGSFORSHARED': '-fPIC',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--enable-ipv6' '--enable-unicode=ucs4' '--prefix=/opt/anaconda1anaconda2anaconda3' '--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' '--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.6 -ltk8.6' 'CPPFLAGS=-I/opt/anaconda1anaconda2anaconda3/include' 'LDFLAGS=-L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed' 'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
+ 'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
+ 'CONFIGURE_CFLAGS': '',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CPPFLAGS': '-I/opt/anaconda1anaconda2anaconda3/include',
+ 'CONFIGURE_LDFLAGS': '-L/opt/anaconda1anaconda2anaconda3/lib '
+                      '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
+ 'CONFIG_ARGS': "'--enable-shared' '--enable-ipv6' '--with-ensurepip=no' "
+                "'--prefix=/opt/anaconda1anaconda2anaconda3' "
+                "'--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' "
+                "'--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib "
+                "-ltcl8.5 -ltk8.5' '--enable-loadable-sqlite-extensions' "
+                "'LDFLAGS=-L/opt/anaconda1anaconda2anaconda3/lib "
+                "-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed' "
+                "'CPPFLAGS=-I/opt/anaconda1anaconda2anaconda3/include' "
+                "'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python2.7',
- 'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work/coverage.info',
- 'COVERAGE_REPORT': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/anaconda1anaconda2anaconda3/include',
+ 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
+ 'COREPYTHONPATH': ':plat-linux',
+ 'COVERAGE_INFO': '/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4/coverage.info',
+ 'COVERAGE_REPORT': '/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
+ 'CPPFLAGS': '-I. -I./Include '
+             '-I/opt/anaconda1anaconda2anaconda3/include '
+             '-I/opt/anaconda1anaconda2anaconda3/include',
  'CXX': 'g++ -pthread',
- 'C_THREADS': 0,
- 'DESTDIRS': '/opt/anaconda1anaconda2anaconda3 /opt/anaconda1anaconda2anaconda3/lib /opt/anaconda1anaconda2anaconda3/lib/python2.7 /opt/anaconda1anaconda2anaconda3/lib/python2.7/lib-dynload',
- 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python2.7',
+ 'DESTDIRS': '/opt/anaconda1anaconda2anaconda3 '
+             '/opt/anaconda1anaconda2anaconda3/lib '
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.5 '
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python2.7/lib-dynload',
+ 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Demo Ext-dummy',
- 'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DISTDIRS': 'Include Lib Misc Ext-dummy',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -47,9 +77,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
+ 'EXT_SUFFIX': '.cpython-35m-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -57,20 +87,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
- 'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
+ 'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
+ 'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
@@ -78,30 +109,24 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_CLOCK_GETRES': 1,
+ 'HAVE_CLOCK_GETTIME': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
- 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
- 'HAVE_CURSES_HAS_KEY': 1,
- 'HAVE_CURSES_IMMEDOK': 1,
- 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
- 'HAVE_CURSES_SYNCOK': 1,
- 'HAVE_CURSES_TYPEAHEAD': 1,
- 'HAVE_CURSES_USE_ENV': 1,
- 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -110,22 +135,32 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
+ 'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
+ 'HAVE_EPOLL_CREATE1': 1,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPM1': 1,
+ 'HAVE_FACCESSAT': 1,
  'HAVE_FCHDIR': 1,
  'HAVE_FCHMOD': 1,
+ 'HAVE_FCHMODAT': 1,
  'HAVE_FCHOWN': 1,
+ 'HAVE_FCHOWNAT': 1,
  'HAVE_FCNTL_H': 1,
  'HAVE_FDATASYNC': 1,
+ 'HAVE_FDOPENDIR': 1,
+ 'HAVE_FEXECVE': 1,
  'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
@@ -133,19 +168,26 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
  'HAVE_FSEEKO': 1,
+ 'HAVE_FSTATAT': 1,
  'HAVE_FSTATVFS': 1,
  'HAVE_FSYNC': 1,
  'HAVE_FTELL64': 0,
  'HAVE_FTELLO': 1,
  'HAVE_FTIME': 1,
  'HAVE_FTRUNCATE': 1,
+ 'HAVE_FUTIMENS': 1,
+ 'HAVE_FUTIMES': 1,
+ 'HAVE_FUTIMESAT': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 1,
  'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 0,
+ 'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
  'HAVE_GETHOSTBYNAME_R': 1,
@@ -163,6 +205,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -170,10 +214,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETSPNAM': 1,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
+ 'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
+ 'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
@@ -181,6 +228,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
+ 'HAVE_IPA_PURE_CONST_BUG': 0,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
@@ -196,45 +244,72 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
+ 'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
+ 'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
+ 'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
+ 'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
+ 'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
+ 'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
+ 'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
+ 'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
+ 'HAVE_MBRTOWC': 1,
  'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMRCHR': 1,
+ 'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
+ 'HAVE_MKFIFOAT': 1,
  'HAVE_MKNOD': 1,
+ 'HAVE_MKNODAT': 1,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
  'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
+ 'HAVE_POSIX_FADVISE': 1,
+ 'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
+ 'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
+ 'HAVE_PWRITE': 1,
  'HAVE_READLINK': 1,
+ 'HAVE_READLINKAT': 1,
+ 'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -244,19 +319,28 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
+ 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
+ 'HAVE_SCHED_H': 1,
+ 'HAVE_SCHED_RR_GET_INTERVAL': 1,
+ 'HAVE_SCHED_SETAFFINITY': 1,
+ 'HAVE_SCHED_SETPARAM': 1,
+ 'HAVE_SCHED_SETSCHEDULER': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
  'HAVE_SEM_UNLINK': 1,
+ 'HAVE_SENDFILE': 1,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
+ 'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
+ 'HAVE_SETPRIORITY': 1,
  'HAVE_SETREGID': 1,
  'HAVE_SETRESGID': 1,
  'HAVE_SETRESUID': 1,
@@ -266,9 +350,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 1,
  'HAVE_SIGACTION': 1,
+ 'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
+ 'HAVE_SIGPENDING': 1,
  'HAVE_SIGRELSE': 1,
+ 'HAVE_SIGTIMEDWAIT': 1,
+ 'HAVE_SIGWAIT': 1,
+ 'HAVE_SIGWAITINFO': 1,
  'HAVE_SNPRINTF': 1,
  'HAVE_SOCKADDR_SA_LEN': 0,
  'HAVE_SOCKADDR_STORAGE': 1,
@@ -281,10 +370,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
+ 'HAVE_STRLCPY': 0,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
@@ -294,14 +385,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
  'HAVE_SYMLINK': 1,
+ 'HAVE_SYMLINKAT': 1,
+ 'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
+ 'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
+ 'HAVE_SYS_IOCTL_H': 1,
+ 'HAVE_SYS_KERN_CONTROL_H': 0,
  'HAVE_SYS_LOADAVG_H': 0,
  'HAVE_SYS_LOCK_H': 0,
  'HAVE_SYS_MKDEV_H': 0,
@@ -312,24 +409,27 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
+ 'HAVE_SYS_SENDFILE_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
- 'HAVE_SYS_SYSMACROS_H': 1,
+ 'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYS_DOMAIN_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
+ 'HAVE_SYS_UIO_H': 1,
  'HAVE_SYS_UN_H': 1,
  'HAVE_SYS_UTSNAME_H': 1,
  'HAVE_SYS_WAIT_H': 1,
+ 'HAVE_SYS_XATTR_H': 1,
  'HAVE_TCGETPGRP': 1,
  'HAVE_TCSETPGRP': 1,
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
  'HAVE_TGAMMA': 1,
- 'HAVE_THREAD_H': 0,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -344,78 +444,111 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
+ 'HAVE_UNLINKAT': 1,
  'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
+ 'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
+ 'HAVE_WAITID': 1,
  'HAVE_WAITPID': 1,
  'HAVE_WCHAR_H': 1,
  'HAVE_WCSCOLL': 1,
+ 'HAVE_WCSFTIME': 1,
+ 'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
+ 'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'HURD_C_THREADS': 0,
- 'INCLDIRSTOMAKE': '/opt/anaconda1anaconda2anaconda3/include /opt/anaconda1anaconda2anaconda3/include /opt/anaconda1anaconda2anaconda3/include/python2.7 /opt/anaconda1anaconda2anaconda3/include/python2.7',
+ 'INCLDIRSTOMAKE': '/opt/anaconda1anaconda2anaconda3/include '
+                   '/opt/anaconda1anaconda2anaconda3/include '
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m '
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
  'INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python2.7',
+ 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython2.7.so.1.0',
+ 'INSTSONAME': 'libpython3.5m.so.1.0',
+ 'IO_H': 'Modules/_io/_iomodule.h',
+ 'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
+ 'LDFLAGS': '-L/opt/anaconda1anaconda2anaconda3/lib '
+            '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed '
+            '-L/opt/anaconda1anaconda2anaconda3/lib '
+            '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython2.7.so',
+ 'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
+ 'LDSHARED': 'gcc -pthread -shared '
+             '-L/opt/anaconda1anaconda2anaconda3/lib '
+             '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed '
+             '-L/opt/anaconda1anaconda2anaconda3/lib '
+             '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python2.7',
+ 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
  'LIBDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBP': '/opt/anaconda1anaconda2anaconda3/lib/python2.7',
  'LIBPC': '/opt/anaconda1anaconda2anaconda3/lib/pkgconfig',
- 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python2.7/config',
- 'LIBRARY': 'libpython2.7.a',
+ 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/config-3.5m',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
- 'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
+ 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
+ 'LIBS': '-lpthread -ldl  -lutil -lrt',
+ 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '',
- 'MACHDEP': 'linux2',
- 'MACHDEPPATH': ':plat-linux2',
- 'MACHDEPS': 'plat-linux2',
+ 'LOG1P_DROPS_ZERO_SIGN': 0,
+ 'MACHDEP': 'linux',
+ 'MACHDEPPATH': ':plat-linux',
+ 'MACHDEPS': 'plat-linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python2.7',
- 'MACH_C_THREADS': 0,
+ 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/opt/anaconda1anaconda2anaconda3/share/man',
- 'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/zipimport.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _stat time _locale _io '
+             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
+ 'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OLDPATH': ':lib-old',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -425,7 +558,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
@@ -433,45 +566,61 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-linux2',
- 'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
- 'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
+ 'PLATDIR': 'plat-linux',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
+ 'PY3LIBRARY': 'libpython3.so',
  'PYLONG_BITS_IN_DIGIT': 0,
  'PYTHON': 'python',
  'PYTHONFRAMEWORK': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
+ 'PYTHONPATH': ':plat-linux',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -g -O2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I./Include -I/opt/anaconda1anaconda2anaconda3/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
+              '-Wstrict-prototypes',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
+                   '-Wall -Wstrict-prototypes '
+                   '-Werror=declaration-after-statement -I. -I./Include '
+                   '-I/opt/anaconda1anaconda2anaconda3/include '
+                   '-I/opt/anaconda1anaconda2anaconda3/include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -I./Include '
+                '-I/opt/anaconda1anaconda2anaconda3/include '
+                '-I/opt/anaconda1anaconda2anaconda3/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 0,
+ 'PY_LDFLAGS': '-L/opt/anaconda1anaconda2anaconda3/lib '
+               '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed '
+               '-L/opt/anaconda1anaconda2anaconda3/lib '
+               '-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 4,
- 'Py_USING_UNICODE': 1,
- 'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
+ 'Py_HASH_ALGORITHM': 0,
+ 'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
+ 'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4',
  'SCRIPTDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
- 'SHLIB_EXT': '".so"',
+ 'SHLIBS': '-lpthread -ldl  -lutil -lrt',
+ 'SHLIB_SUFFIX': '.so',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -492,36 +641,39 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SRCDIRS': 'Parser Objects Python Modules',
+ 'SOABI': 'cpython-35m-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
- 'STRINGLIB_HEADERS': '\\',
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
- 'SUBDIRSTOO': 'Include Lib Misc Demo',
+ 'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '-I/opt/anaconda1anaconda2anaconda3/include',
- 'TCLTK_LIBS': '-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.6 -ltk8.6',
- 'TESTOPTS': '-l',
+ 'TCLTK_LIBS': '-L/opt/anaconda1anaconda2anaconda3/lib '
+               '-ltcl8.5 -ltk8.5',
+ 'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/conda/feedstock_root/build_artifacts/python_1525790729080/work ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4 '
+               './python',
  'TESTPYTHONOPTS': '',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4 '
+               './python ./Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
+ 'TIMEMODULE_LIB': 'rt',
  'TIME_WITH_SYS_TIME': 1,
- 'TKPATH': ':lib-tk',
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_TOOLBOX_OBJECT_GLUE': 0,
+ 'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '2.7',
+ 'VERSION': '3.5',
  'WANT_SIGFPE_HANDLER': 0,
- 'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
@@ -533,11 +685,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
- 'abs_srcdir': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
- 'build': 'x86_64-pc-linux-gnu',
+ 'abs_builddir': '/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4',
+ 'abs_srcdir': '/feedstock_root/build_artefacts/python_1502329017658/work/Python-3.5.4',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
- 'host': 'x86_64-pc-linux-gnu',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
  'srcdir': '.'}
